import os
import stripe
import logging
log = logging.getLogger(__name__)

def create_stripe_payment_intent(
        amount: float, 
        booking_id: str,
        currency: str = "AUD",
        confirm_timeout: int = 900, # 15 minutes
                                 ):
    try:
        payment_intent = stripe.PaymentIntent.create(
            api_key=os.environ['STRIPE_API_KEY'],
            amount=int(amount*100),
            currency=currency,
            payment_method_types=['card'], # TODO add more payment methods
            description="payment for booking: " + booking_id,
            metadata={
                "booking_id": booking_id
            },
            confirm_timeout=confirm_timeout,
        )
        return {"StripeClientSecret": payment_intent["client_secret"]}
    except Exception as e:
        log.error(e)
        return {
            "error": "Failed to create payment intent",
            "StripeClientSecret": None
        }